@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: warp
 version: 3.2.3
-id: warp-3.2.3-b193a405602f21fe67837dcb996939ee
-key: warp_34gPYYxNi5M5hgmECVctSj
+id: warp-3.2.3-0fe962c9e43b4ce1b68b117c1dfdd0a0
+key: warp_8W10cB6FB9e74OQAjgSq2s
 license: MIT
 maintainer: michael@snoyman.com
 stability: Stable
@@ -48,30 +48,30 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-3.2.3
-hs-libraries: HSwarp-3.2.3-34gPYYxNi5M5hgmECVctSj
+hs-libraries: HSwarp-3.2.3-8W10cB6FB9e74OQAjgSq2s
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
+    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
-    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    http-date-0.0.6.1-ba351a4841239284d88745a26c501ccf
-    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
-    http2-1.5.2-c17f65710580a09ffe9d21de5a311fa3
+    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
+    http-date-0.0.6.1-757f4a31bc2dcd5d0b4e75509958696c
+    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
+    http2-1.5.4-328e73d4110ea2a7bdc57af8b03bb3c5
     iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     simple-sendfile-0.2.21-b4189a70d5e750749d989e840422f185
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
-    streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
-    vault-0.3.0.6-8b1ddbd07c6eb1be1ee9aee781649e3c
-    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
+    vault-0.3.0.6-2c2444df5306907b16aaa509d25c29c9
+    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
     word8-0.1.2-9a296ac80618be494d93f29b398e749d
 haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
 haddock-html: /usr/share/doc/haskell-warp/html
